@@ -3,6 +3,7 @@ package tfupdate
 import (
 	"context"
 	"reflect"
+	"regexp"
 	"testing"
 
 	"github.com/hashicorp/hcl/v2"
@@ -11,36 +12,41 @@ import (
 
 func TestNewModuleUpdater(t *testing.T) {
 	cases := []struct {
-		name    string
-		version string
-		want    Updater
-		ok      bool
+		name            string
+		sourceMatchType string
+		version         string
+		want            Updater
+		ok              bool
 	}{
 		{
-			name:    "terraform-aws-modules/vpc/aws",
-			version: "2.17.0",
+			name:            "terraform-aws-modules/vpc/aws",
+			sourceMatchType: "full",
+			version:         "2.17.0",
 			want: &ModuleUpdater{
-				name:    "terraform-aws-modules/vpc/aws",
-				version: "2.17.0",
+				name:      "terraform-aws-modules/vpc/aws",
+				nameRegex: nil,
+				version:   "2.17.0",
 			},
 			ok: true,
 		},
 		{
-			name:    "",
-			version: "2.17.0",
-			want:    nil,
-			ok:      false,
+			name:            "",
+			sourceMatchType: "full",
+			version:         "2.17.0",
+			want:            nil,
+			ok:              false,
 		},
 		{
-			name:    "terraform-aws-modules/vpc/aws",
-			version: "",
-			want:    nil,
-			ok:      false,
+			name:            "terraform-aws-modules/vpc/aws",
+			sourceMatchType: "full",
+			version:         "",
+			want:            nil,
+			ok:              false,
 		},
 	}
 
 	for _, tc := range cases {
-		got, err := NewModuleUpdater(tc.name, tc.version)
+		got, err := NewModuleUpdater(tc.name, tc.version, nil)
 		if tc.ok && err != nil {
 			t.Errorf("NewModuleUpdater() with name = %s, version = %s returns unexpected err: %+v", tc.name, tc.version, err)
 		}
@@ -57,12 +63,13 @@ func TestNewModuleUpdater(t *testing.T) {
 
 func TestUpdateModule(t *testing.T) {
 	cases := []struct {
-		filename string
-		src      string
-		name     string
-		version  string
-		want     string
-		ok       bool
+		filename        string
+		src             string
+		name            string
+		sourceMatchType string
+		version         string
+		want            string
+		ok              bool
 	}{
 		{
 			filename: "main.tf",
@@ -72,8 +79,9 @@ module "vpc" {
   version = "2.17.0"
 }
 `,
-			name:    "terraform-aws-modules/vpc/aws",
-			version: "2.18.0",
+			name:            "terraform-aws-modules/vpc/aws",
+			version:         "2.18.0",
+			sourceMatchType: "full",
 			want: `
 module "vpc" {
   source  = "terraform-aws-modules/vpc/aws"
@@ -94,8 +102,9 @@ module "vpc2" {
   version = "2.17.0"
 }
 `,
-			name:    "terraform-aws-modules/vpc/aws",
-			version: "2.18.0",
+			name:            "terraform-aws-modules/vpc/aws",
+			version:         "2.18.0",
+			sourceMatchType: "full",
 			want: `
 module "vpc1" {
   source  = "terraform-aws-modules/vpc/aws"
@@ -116,8 +125,9 @@ module "vpc" {
   version = "2.17.0"
 }
 `,
-			name:    "terraform-aws-modules/hoge/aws",
-			version: "2.18.0",
+			name:            "terraform-aws-modules/hoge/aws",
+			sourceMatchType: "full",
+			version:         "2.18.0",
 			want: `
 module "vpc" {
   source  = "terraform-aws-modules/vpc/aws"
@@ -133,8 +143,9 @@ module "vpc" {
   source = "terraform-aws-modules/vpc/aws"
 }
 `,
-			name:    "terraform-aws-modules/vpc/aws",
-			version: "2.18.0",
+			name:            "terraform-aws-modules/vpc/aws",
+			sourceMatchType: "full",
+			version:         "2.18.0",
 			want: `
 module "vpc" {
   source = "terraform-aws-modules/vpc/aws"
@@ -149,12 +160,67 @@ module "vpc" {
   source = "git::https://example.com/vpc.git?ref=v1.2.0"
 }
 `,
-			name:    "git::https://example.com/vpc.git",
-			version: "1.3.0",
+			name:            "git::https://example.com/vpc.git",
+			sourceMatchType: "full",
+			version:         "1.3.0",
 			want: `
 module "vpc" {
   source = "git::https://example.com/vpc.git?ref=v1.3.0"
 }
+`,
+			ok: true,
+		},
+		{
+			filename: "main.tf",
+			src: `
+module "vpc1" {
+  source  = "terraform-aws-modules.git/vpc/aws1"
+  version = "2.17.0"
+}
+module "vpc2" {
+  source  = "terraform-aws-modules.git/vpc/aws2"
+  version = "2.17.0"
+}
+`,
+			name:            "terraform-aws-modules.git/",
+			version:         "2.18.0",
+			sourceMatchType: "regex",
+			want: `
+module "vpc1" {
+  source  = "terraform-aws-modules.git/vpc/aws1"
+  version = "2.18.0"
+}
+module "vpc2" {
+  source  = "terraform-aws-modules.git/vpc/aws2"
+  version = "2.18.0"
+}
+`,
+			ok: true,
+		},
+		{
+			filename: "main.tf",
+			src: `
+module "vpc1" {
+  source  = "terraform-aws-modules.git/vpc/aws1"
+  version = "2.17.0"
+}
+module "vpc2" {
+  source  = "terraform-aws-modules.git/vpc/aws2"
+  version = "2.17.0"
+}
+`,
+			name:            "terraform-aws-modules\\.git/.+",
+			version:         "2.18.0",
+			sourceMatchType: "regex",
+			want: `
+module "vpc1" {
+  source  = "terraform-aws-modules.git/vpc/aws1"
+  version = "2.18.0"
+}
+module "vpc2" {
+  source  = "terraform-aws-modules.git/vpc/aws2"
+  version = "2.18.0"
+}
 `,
 			ok: true,
 		},
@@ -162,7 +228,13 @@ module "vpc" {
 
 	for _, tc := range cases {
 		u := &ModuleUpdater{
-			name:    tc.name,
+			name: tc.name,
+			nameRegex: func() *regexp.Regexp {
+				if tc.sourceMatchType == "regex" {
+					return regexp.MustCompile(tc.name)
+				}
+				return nil
+			}(),
 			version: tc.version,
 		}
 		f, diags := hclwrite.ParseConfig([]byte(tc.src), tc.filename, hcl.Pos{Line: 1, Column: 1})
